# If any of the following macros should be set otherwise,
# you can wrap any of them with the following conditions:
# - %%if 0%%{centos} == 7
# - %%if 0%%{?rhel} == 7
# - %%if 0%%{?fedora} == 23
# Or just test for particular distribution:
# - %%if 0%%{centos}
# - %%if 0%%{?rhel}
# - %%if 0%%{?fedora}
#
# Be aware, on centos, both %%rhel and %%centos are set. If you want to test
# rhel specific macros, you can use %%if 0%%{?rhel} && 0%%{?centos} == 0 condition.
# (Don't forget to replace double percentage symbol with single one in order to apply a condition)

# Generate devel rpm
%global with_devel 1
# Build project from bundled dependencies
%global with_bundled 0
# Build with debug info rpm
%global with_debug 0
# Run tests in check section
# Cyclic deps between gomaga and ginkgo
%global with_check 0
# Generate unit-test rpm
%global with_unit_test 1

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         onsi
%global repo            ginkgo
# https://github.com/onsi/ginkgo
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          7f8ab55aaf3b86885aa55b762e803744d1674700
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        1.1.0
Release:        11%{?dist}
Summary:        A Golang BDD Testing Framework
License:        MIT
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz
# Upstream fix for aarch64 a0fde42
Patch1:         0001-Add-linux_arm64-support.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 aarch64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%description
%{summary}

%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
%endif

Provides:      golang(%{import_path}) = %{version}-%{release}
Provides:      golang(%{import_path}/config) = %{version}-%{release}
Provides:      golang(%{import_path}/extensions/table) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/convert) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/interrupthandler) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/nodot) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/testrunner) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/testsuite) = %{version}-%{release}
Provides:      golang(%{import_path}/ginkgo/watch) = %{version}-%{release}
Provides:      golang(%{import_path}/integration) = %{version}-%{release}
Provides:      golang(%{import_path}/reporters) = %{version}-%{release}
Provides:      golang(%{import_path}/reporters/stenographer) = %{version}-%{release}
Provides:      golang(%{import_path}/types) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.

%if 0%{?with_unit_test}
%package unit-test
Summary:         Unit tests for %{name} package

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
BuildRequires: golang(github.com/onsi/gomega)
BuildRequires: golang(github.com/onsi/gomega/gbytes)
BuildRequires: golang(github.com/onsi/gomega/gexec)
BuildRequires: golang(github.com/onsi/gomega/ghttp)
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}
Requires:        golang(github.com/onsi/gomega)
Requires:        golang(github.com/onsi/gomega/gbytes)
Requires:        golang(github.com/onsi/gomega/gexec)
Requires:        golang(github.com/onsi/gomega/ghttp)

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}
%patch1 -p1 -b .arm64

%build

%install
# source codes for building projects
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . \( -iname "*.go" -or -iname "*.s" \) \! -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done

# testing files for this project
%if 0%{?with_unit_test}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test-devel.file-list
for file in $(find . -iname "*_test.go") ; do
    dirprefix=$(dirname $file)
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$dirprefix
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test-devel.file-list

    while [ "$dirprefix" != "." ]; do
        echo "%%dir %%{gopath}/src/%%{import_path}/$dirprefix" >> devel.file-list
        dirprefix=$(dirname $dirprefix)
    done
done
%endif

sort -u -o devel.file-list devel.file-list

%check
%if 0%{?with_check} && 0%{?with_unit_test}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
# No dependency directories so far

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}/ginkgo/nodot
%gotest %{import_path}/ginkgo/testsuite
%gotest %{import_path}/integration
%gotest %{import_path}/internal/codelocation
%gotest %{import_path}/internal/containernode
%gotest %{import_path}/internal/failer
%gotest %{import_path}/internal/leafnodes
%gotest %{import_path}/internal/remote
%gotest %{import_path}/internal/spec
%gotest %{import_path}/internal/specrunner
%gotest %{import_path}/internal/suite
%gotest %{import_path}/internal/writer
%gotest %{import_path}/reporters
%gotest %{import_path}/types
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files devel -f devel.file-list
%license LICENSE
%doc CHANGELOG.md README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}

%if 0%{?with_unit_test}
%files unit-test -f unit-test-devel.file-list
%license LICENSE
%doc CHANGELOG.md README.md
%endif

%changelog
* Mon Jan 09 2017 Jan Chaloupka <jchaloup@redhat.com> - 1.1.0-11
- Add missing Provides
  related: #1214619

* Mon Jan 09 2017 Jan Chaloupka <jchaloup@redhat.com> - 1.1.0-10
- Bump to upstream 7f8ab55aaf3b86885aa55b762e803744d1674700
  related: #1214619

* Tue Aug 09 2016 jchaloup <jchaloup@redhat.com> - 1.1.0-9
- Polish spec file, enable devel and unit-test for epel7
  related: #1214619

* Thu Jul 21 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-8
- https://fedoraproject.org/wiki/Changes/golang1.7

* Tue Feb 23 2016 Peter Robinson <pbrobinson@fedoraproject.org> 1.1.0-7
- Add patch for aarch64
- Use %%license

* Mon Feb 22 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-6
- https://fedoraproject.org/wiki/Changes/golang1.6

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Aug 20 2015 jchaloup <jchaloup@redhat.com> - 1.1.0-4
- Update spec file to spec-2.0
  related: #1214619

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 jchaloup <jchaloup@redhat.com> - 1.1.0-2
- Bump to upstream 462326b1628e124b23f42e87a8f2750e3c4e2d24
  related: #1214619

* Thu Apr 23 2015 jchaloup <jchaloup@redhat.com> - 1.1.0-1
- Bump to upstream dbb5c6caf33238b57facc1d975b1aaca6b90288c
  resolves: #1214619

* Sat Feb 07 2015 jchaloup <jchaloup@redhat.com> - 0-0.4.git17ea479
- Add buildtime dependency on github.com/onsi/gomega
- Fix installtime dependency on github.com/onsi/gomega
  related: #1148456

* Fri Feb 06 2015 jchaloup <jchaloup@redhat.com> - 0-0.3.git17ea479
- Bump to upstream 17ea479729ee427265ac1e913443018350946ddf
  related: #1148456

* Mon Oct 13 2014 jchaloup <jchaloup@redhat.com> - 0-0.2.git90d6a47
- BuildArch to ExclusiveArch

* Wed Oct 01 2014 Jan Chaloupka <jchaloup@redhat.com> - 0-0.1.git90d6a47
- First package for Fedora
